@@ -233,6 +233,32 @@ const expectedXmlWithProcInstAndDirectives = `<?xml version="1.0"?>
 `
 
 var xmlScenarios = []formatScenario{
+	{
+		skipDoc:  true,
+		input:    "  <root>value<!-- comment--> </root>",
+		expected: "root: value # comment\n",
+	},
+	{
+		skipDoc:       true,
+		input:         "value<root>value</root>",
+		expectedError: "bad file 'sample.yml': invalid XML: Encountered chardata [value] outside of XML node",
+		scenarioType:  "decode-error",
+	},
+	{
+		skipDoc:  true,
+		input:    "<root><!-- comment-->value</root>",
+		expected: "# comment\nroot: value\n",
+	},
+	{
+		skipDoc:  true,
+		input:    "<root> <!-- comment--></root>",
+		expected: "root: # comment\n",
+	},
+	{
+		skipDoc:  true,
+		input:    "<root>value<!-- comment-->anotherValue </root>",
+		expected: "root:\n    # comment\n    - value\n    - anotherValue\n",
+	},
 	{
 		description:    "Parse xml: simple",
 		subdescription: "Notice how all the values are strings, see the next example on how you can fix that.",
@@ -264,6 +290,12 @@ var xmlScenarios = []formatScenario{
 		input:          "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cat legs=\"4\">meow</cat>",
 		expected:       "+p_xml: version=\"1.0\" encoding=\"UTF-8\"\ncat:\n    +content: meow\n    +@legs: \"4\"\n",
 	},
+	{
+		description:    "Parse xml: content split between comments/children",
+		subdescription: "Multiple content texts are collected into a sequence.",
+		input:          "<root>  value  <!-- comment-->anotherValue <a>frog</a> cool!</root>",
+		expected:       "root:\n    +content: # comment\n        - value\n        - anotherValue\n        - cool!\n    a: frog\n",
+	},
 	{
 		description:    "Parse xml: custom dtd",
 		subdescription: "DTD entities are processed as directives.",
@@ -481,6 +513,13 @@ func testXMLScenario(t *testing.T, s formatScenario) {
 		prefs := NewDefaultXmlPreferences()
 		prefs.SkipDirectives = true
 		test.AssertResultWithContext(t, s.expected, mustProcessFormatScenario(s, NewXMLDecoder(prefs), NewXMLEncoder(2, prefs)), s.description)
+	case "decode-error":
+		result, err := processFormatScenario(s, NewXMLDecoder(NewDefaultXmlPreferences()), NewYamlEncoder(2, false, ConfiguredYamlPreferences))
+		if err == nil {
+			t.Errorf("Expected error '%v' but it worked: %v", s.expectedError, result)
+		} else {
+			test.AssertResultComplexWithContext(t, s.expectedError, err.Error(), s.description)
+		}
 	case "encode-error":
 		result, err := processFormatScenario(s, NewYamlDecoder(ConfiguredYamlPreferences), NewXMLEncoder(2, NewDefaultXmlPreferences()))
 		if err == nil {
